==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","Email");
define("_REALNAME","Gerek sim");
define("_FUNCTIONS","Fonksiyonlar");
define("_PREVIOUS","nceki Sayfa");
define("_MEMBERSLIST","ye Listesi");
define("_GREETINGS","Son Kayt Olan yemiz:");
define("_SORTBY","Sralama:");
define("_MNICKNAME","nickname");
define("_MREALNAME","gerek isim");
define("_MEMAIL","email");
define("_MURL","url");
define("_ONLINEREG","Online Kaytl Kullanclar:");
define("_WEHAVE","u an");
define("_MREGISTERED","kaytl kullancmz var. Bunlardan");
define("_MREGONLINE","kaytl kullanc u an sitede bulunuyor.");
define("_REGSOFAR","kaytl kullanc bulunuyor.");
define("_USERSFOUND","kullanc bulundu:");
define("_USERSSHOWN","kullanc grntlendi");
define("_NOMEMBERS","Kullanc bulunamad:");
define("_PAGES","Sayfa");
define("_HOMEPAGE","AnaSayfa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","Email");
define("_REALNAME","Gerek sim");
define("_FUNCTIONS","Fonksiyonlar");
define("_PREVIOUS","nceki Sayfa");
define("_MEMBERSLIST","ye Listesi");
define("_GREETINGS","Son Kayt Olan yemiz:");
define("_SORTBY","Sralama:");
define("_MNICKNAME","nickname");
define("_MREALNAME","gerek isim");
define("_MEMAIL","email");
define("_MURL","url");
define("_ONLINEREG","Online Kaytl Kullanclar:");
define("_WEHAVE","u an");
define("_MREGISTERED","kaytl kullancmz var. Bunlardan");
define("_MREGONLINE","kaytl kullanc u an sitede bulunuyor.");
define("_REGSOFAR","kaytl kullanc bulunuyor.");
define("_USERSFOUND","kullanc bulundu:");
define("_USERSSHOWN","kullanc grntlendi");
define("_NOMEMBERS","Kullanc bulunamad:");
define("_PAGES","Sayfa");
define("_HOMEPAGE","AnaSayfa");

?>
